@@ -35,8 +35,10 @@ impl Factory {
         })
     }
 
-    pub fn from_cmake(compile_group: &cmake::codemodel::target::CompileGroup) -> Result<Self> {
-        use crate::cmake::codemodel::Language;
+    pub fn from_cmake(
+        compile_group: &cmake::file_api::codemodel::target::CompileGroup,
+    ) -> Result<Self> {
+        use crate::cmake::file_api::codemodel::Language;
         assert!(
             compile_group.language == Language::C || compile_group.language == Language::Cpp,
             "Generating bindings for languages other than C/C++ is not supported"
@@ -63,7 +65,27 @@ impl Factory {
         })
     }
 
-    /// Set the linker used to determine the sysroot to be used for generating bindings.
+    pub fn new() -> Self {
+        Default::default()
+    }
+
+    /// Set the clang args that need to be passed down to the Bindgen instance.
+    pub fn with_clang_args<S>(mut self, clang_args: impl IntoIterator<Item = S>) -> Self
+    where
+        S: Into<String>,
+    {
+        self.clang_args
+            .extend(clang_args.into_iter().map(Into::into));
+        self
+    }
+
+    /// Set the sysroot to be used for generating bindings.
+    pub fn with_sysroot(mut self, sysroot: impl Into<PathBuf>) -> Self {
+        self.sysroot = Some(sysroot.into());
+        self
+    }
+
+    /// Set the linker used to determine the sysroot to be used for generating bindings, if the sysroot is not explicitly passed.
     pub fn with_linker(mut self, linker: impl Into<PathBuf>) -> Self {
         self.linker = Some(linker.into());
         self
